@@ -922,7 +922,8 @@ void KCalculator::slotMemStoreclicked() {
 //------------------------------------------------------------------------------
 void KCalculator::slotNumberclicked(int number_clicked) {
 
-    calc_display->enterDigit(number_clicked);
+	calc_display->enterDigit(number_clicked);
+	core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1700,7 +1701,6 @@ void KCalculator::slotSetSimpleMode() {
 
 	action_constants_show_->setChecked(false);
 	action_constants_show_->setEnabled(false);
-	action_bitset_show_->setChecked(false);
 	action_bitset_show_->setEnabled(false);
 	showMemButtons(false);
 	showScienceButtons(false);
@@ -1723,6 +1723,9 @@ void KCalculator::slotSetSimpleMode() {
 	constants_menu_ = 0;
 
 	KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::simple);
+	// must be done after setting the calculator mode because the
+	// slotBitsetshow slot should save the state only in numeral mode
+	action_bitset_show_->setChecked(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1733,7 +1736,6 @@ void KCalculator::slotSetScienceMode() {
 
 	action_constants_show_->setEnabled(true);
 	action_constants_show_->setChecked(KCalcSettings::showConstants());
-	action_bitset_show_->setChecked(false);
 	action_bitset_show_->setEnabled(false);
 
 	// show some individual buttons
@@ -1759,6 +1761,9 @@ void KCalculator::slotSetScienceMode() {
 	}
 
 	KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::science);
+	// must be done after setting the calculator mode because the
+	// slotBitsetshow slot should save the state only in numeral mode
+	action_bitset_show_->setChecked(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1769,7 +1774,6 @@ void KCalculator::slotSetStatisticMode() {
 
 	action_constants_show_->setEnabled(true);
 	action_constants_show_->setChecked(KCalcSettings::showConstants());
-	action_bitset_show_->setChecked(false);
 	action_bitset_show_->setEnabled(false);
 
 	// show some individual buttons
@@ -1795,6 +1799,9 @@ void KCalculator::slotSetStatisticMode() {
 	}
 
 	KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::statistics);
+	// must be done after setting the calculator mode because the
+	// slotBitsetshow slot should save the state only in numeral mode
+	action_bitset_show_->setChecked(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1977,7 +1984,9 @@ void KCalculator::slotConstantsShow(bool toggled) {
 void KCalculator::slotBitsetshow(bool toggled) {
 
 	mBitset->setVisible(toggled);
-	KCalcSettings::setShowBitset(toggled);
+	if (KCalcSettings::calculatorMode() == KCalcSettings::EnumCalculatorMode::numeral) {
+		KCalcSettings::setShowBitset(toggled);
+	}
 }
 
 //------------------------------------------------------------------------------
@@ -2047,6 +2056,7 @@ void KCalculator::updateDisplay(UpdateFlags flags) {
 
 	if(flags & UPDATE_FROM_CORE) {
 		calc_display->updateFromCore(core, (flags & UPDATE_STORE_RESULT) != 0);
+		core.setOnlyUpdateOperation(true);
 	} else {
 		calc_display->update();
 	}
